Module blaxel.core.sandbox.client.models.subdirectory
=====================================================

Classes
-------

`Subdirectory(name: str, path: str)`
:   Attributes:
        name (str):
        path (str):
    
    Method generated by attrs for class Subdirectory.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: str`
    :

    `path: str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :